#
# spec file for package ansible-runner
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define module_name ansible-runner

%{?sle15_python_module_pythons}
%if 0%{?suse_version} < 1550
# Leap15, SLES15
%if %pythons == "python310"
%define ansible_python python310
%define ansible_python_executable python3.10
%define ansible_python_sitelib %python310_sitelib
%endif
%if %pythons == "python311"
%define ansible_python python311
%define ansible_python_executable python3.11
%define ansible_python_sitelib %python311_sitelib
%endif
%else
# Tumbleweed
%define pythons python3
%define ansible_python python3
%define ansible_python_executable python3
%define ansible_python_sitelib %python3_sitelib
%endif

Name:           ansible-runner
Version:        2.3.4
Release:        1.1
Summary:        Run ansible-playbook inside an execution environment
License:        Apache-2.0
URL:            https://github.com/ansible/%{module_name}
Source:         https://files.pythonhosted.org/packages/source/a/%{module_name}/%{module_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  python-rpm-macros
# https://github.com/ansible/ansible-runner/blob/devel/setup.cfg#L31
BuildRequires:  %{ansible_python}-base >= 3.8
BuildRequires:  %{ansible_python}-setuptools
BuildRequires:  %{ansible_python}-pbr
# https://github.com/ansible/ansible-runner/blob/devel/setup.cfg#L32
BuildRequires:  ansible-core
BuildRequires:  %{ansible_python}-packaging
BuildRequires:  %{ansible_python}-pexpect >= 4.5
BuildRequires:  %{ansible_python}-python-daemon
BuildRequires:  %{ansible_python}-PyYAML
BuildRequires:  %{ansible_python}-six
# https://github.com/ansible/ansible-runner/blob/devel/setup.cfg#L38
# importlib-metadata not required, as we are using python3.10 or higher
# SECTION test requirements
# https://github.com/ansible/ansible-runner/blob/devel/test/requirements.txt
BuildRequires:  %{ansible_python}-pytest
BuildRequires:  %{ansible_python}-pytest-mock
BuildRequires:  %{ansible_python}-pytest-timeout
BuildRequires:  %{ansible_python}-pytest-xdist
# /SECTION
BuildRequires:  fdupes
# https://github.com/ansible/ansible-runner/blob/devel/setup.cfg#L32
Requires:       %{ansible_python}-packaging
Requires:       %{ansible_python}-pexpect >= 4.5
Requires:       %{ansible_python}-python-daemon
Requires:       %{ansible_python}-PyYAML
Requires:       %{ansible_python}-six
Requires:       %{ansible_python}-setuptools
# https://github.com/ansible/ansible-runner/blob/devel/setup.cfg#L38
# importlib-metadata not required, as we are using python3.10 or higher

%description
Consistent Ansible Python API and CLI with container and process isolation runtime capabilities

%prep
%setup -q -n %{module_name}-%{version}

%build
%python_build

%install
%python_install
%fdupes %{buildroot}%{ansible_python_sitelib}

sed -i '1s|^#!%{_bindir}/env bash$|#!%{_bindir}/bash|' %{buildroot}/%{_datadir}/%{module_name}/utils/entrypoint.sh

%check
# disable coverage tests
sed -i '/cov/d' pytest.ini

# Ignored tests, upstream bug report:
# https://github.com/ansible/ansible-runner/issues/1237
#
IGNORED_TESTS='test_callback_plugin_task_args_leak[playbook0] or '
IGNORED_TESTS+='test_resolved_actions[playbook0] or '
IGNORED_TESTS+='test_playbook_on_stats_summary_fields or '
IGNORED_TESTS+='test_multiline_blank_write[pexpect]'
export PATH=%{buildroot}%{_bindir}:$PATH
%pytest -k "not ($IGNORED_TESTS)"

%files
%doc README.md
%license LICENSE.md
%{_bindir}/%{module_name}
%{ansible_python_sitelib}/ansible_runner
%{ansible_python_sitelib}/ansible_runner-*-info
%dir %{_datadir}/%{module_name}/
%dir %{_datadir}/%{module_name}/utils/
%{_datadir}/%{module_name}/utils/entrypoint.sh

%changelog
* Thu Sep  7 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 2.3.4:
  * [2.3 backport] Give more detail when we cannot process a
    non-JSON streamed line (#1186) by @AlanCoding in
    https://github.com/ansible/ansible-runner/pull/1258
* Wed May 31 2023 Johannes Kastl <kastl@b1-systems.de>
- update to 2.3.3:
  * [backport][release_2.3] Add `python_requires = >= 3.8` (#1206)
    by @Shrews in
    https://github.com/ansible/ansible-runner/pull/1212
  * [backport][release_2.3] Add license and classifiers metadata
    (#1213) by @Shrews in
    https://github.com/ansible/ansible-runner/pull/1214
  * [2.3 backport] Remove pkg_resources use (#1224) by
    @nitzmahone in
    https://github.com/ansible/ansible-runner/pull/1230
* Mon May 15 2023 Johannes Kastl <kastl@b1-systems.de>
- modify %%if-condition to allow building for python3.10 or
  python3.11 on SLES15
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- change python version on Leap15/SLES15 to python3.11 to use the
  new stack supported by SUSE
* Thu Apr 20 2023 Johannes Kastl <kastl@b1-systems.de>
- LARGE update to 2.3.2
  changelogs:
  * https://github.com/ansible/ansible-runner/releases/tag/1.4.8
  * https://github.com/ansible/ansible-runner/releases/tag/1.4.9
  * https://github.com/ansible/ansible-runner/releases/tag/2.0.0
  * https://github.com/ansible/ansible-runner/releases/tag/2.0.1
  * https://github.com/ansible/ansible-runner/releases/tag/2.0.2
  * https://github.com/ansible/ansible-runner/releases/tag/2.0.3
  * https://github.com/ansible/ansible-runner/releases/tag/2.0.4
  * https://github.com/ansible/ansible-runner/releases/tag/2.1.1
  * https://github.com/ansible/ansible-runner/releases/tag/2.1.2
  * https://github.com/ansible/ansible-runner/releases/tag/2.1.3
  * https://github.com/ansible/ansible-runner/releases/tag/2.1.4
  * https://github.com/ansible/ansible-runner/releases/tag/2.2.0
  * https://github.com/ansible/ansible-runner/releases/tag/2.2.1
  * https://github.com/ansible/ansible-runner/releases/tag/2.2.2
  * https://github.com/ansible/ansible-runner/releases/tag/2.3.0
  * https://github.com/ansible/ansible-runner/releases/tag/2.3.1
  * https://github.com/ansible/ansible-runner/releases/tag/2.3.2
* Tue Apr 26 2022 pgajdos@suse.com
- do not require python-mock: the testsuite is not running anyway
  and newer testsuite (e. g. 2.1.3) will not use mock at all
  https://trello.com/c/S6eADbii/64-remove-python-mock
* Sun May 23 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.4.7
  * Fixed an issue where byte sequences in the output that are not
    interpretable as UTF-8 would break the job execution.
  * Fixed a bug that broke Ansible playbook execution prior to
    version 2.8 of Ansible
  * Fix an issue with --process_isoloation_*_ paths parsing cli args
  * Switch extravar format so we can support more than just string
    types
  * Make sure job events folder is created earlier to prevent
    errors when using immediately after starting a runner job
  * Annotate all runner_on events with start/end/duration times
- Drop 0001-Use-the-correct-python-executable-for-tests.patch
* Thu Feb 20 2020 Lars Vogdt <lars@linux-schulserver.de>
- update to 1.4.4:
  + Fix some unicode issues when using command line override on python 2.7
  + Fix an issue with file handles not closing on the pexpect pty
  + Fix missing ssh_key parameter from module interface
  + Fix a bug where the ssh agent process would hang around after
    process isolation exit causing a failure to remove temporary directories
  1.4.2 (2019-10-04)
  + Reverted ansible-runner --version to print a semantic version number
  1.4.1 (2019-10-03)
  + Fixed a bug that prevented ANSIBLE_HOST_KEY_CHECKING from being respected
  1.4.0 (2019-09-20)
  + Added changed count to stats data
  + Added initial support for gathering performance statistics using
    the system's cgroup interface
  + Fix command line args override missing from module run kwargs
  + Omit inventory argument entirely if no inventory content is supplied
    this allows ansible to pick up inventory from implicit locations and ansible.cfg
  + Fix an issue where Runner wouldn't properly clean up process
    isolation temporary directories
  + Fix error generated if unsafe parameter is used on vars prompt tasks
  + Fix an issue where additional callback plugins weren't being
    used when defined in the environment
  + Fix an issue where Runner would stop returning events after the
    playbook finished when using run_async
  + Fix an issue where unicode in task data would cause Runner to fail
  + Fix issues using vaulted data that would cause Runner to fail
  + Fix an issue where artifact-dir was only allowed in ad-hoc mode
- run fdupes
- remove upstreamed patch:
  0001-Use-the-correct-python-executable-for-tests.patch
- disable tests again for now
* Tue Jun  4 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 1.3.4:
  * make class __name__ match Ansible expectation
  * bundle six.ensure_str to avoid pinning to a new six version
  * Updating for 1.3.4 release
  * Adopt modified upstream packaging
  * Add missing lockfile RPM dependency
  * Fix an issue with missing options
  * port old callback tests to integration folder
  * Fix missing toplevel host events docs issue
  * Move integration data folder, add new test
- fix license - ansible-runner also contains code licensed under
  GPL-3.0-or-later
* Sat Apr 27 2019 Thomas Bechtold <tbechtold@suse.com>
- enable tests in %%check
- add 0001-Use-the-correct-python-executable-for-tests.patch to fix
  tests with python3
* Wed Apr 24 2019 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 1.3.3)
